#!/usr/bin/env python
'''get CPU temperatures and output to stdout in JSON format'''
import re
import sys
import time
import json
import sched
import logging
import argparse
import subprocess
import statistics

logging.basicConfig(
    format='%(message)s',
    stream=sys.stdout,
    level=logging.DEBUG
)


def log_temperature(args, cron):
    '''schedule next call, get temperature and output it'''
    cron.enter(args.interval, 5, log_temperature, (args, cron))
    try:
        core_temps = {'core_'+match[0].decode(): float(match[1]) for match in
                      re.findall(rb'^Core (\d+):\W+(\d+?\.\d+?).+?C?$',
                                 subprocess.check_output('sensors'),
                                 re.MULTILINE)}
        logging.info('%s', json.dumps(core_temps))
    except Exception as ex:
        logging.warning('ERROR: %s', str(ex))


if __name__ == '__main__':
    '''main function'''
    parser = argparse.ArgumentParser(
        description='read and log cpu temperatures once per [interval]')
    parser.add_argument(
        'interval', type=float, default=1.0, nargs='?',
        help='interval, default: 1.0')
    args = parser.parse_args()
    cron = sched.scheduler(time.time, time.sleep)
    cron.enter(args.interval, 5, log_temperature, (args, cron))
    cron.run(blocking=True)
