#!/usr/bin/env python
'''read systemd journal'''
import sys
import csv
import json
import argparse

from systemd import journal


if __name__ == '__main__':
    '''read syslog entries with tag "identifier"'''
    parser = argparse.ArgumentParser(description='read temperature logs')
    parser.add_argument('identifier', default='temperature-logger', nargs='?',
                        help='syslog tag, default: "temperature-logger"')
    args = parser.parse_args()
    reader = journal.Reader()
    reader.add_match(SYSLOG_IDENTIFIER=args.identifier)
    datas = []
    for entry in reader:
        timestamp = entry.get('__REALTIME_TIMESTAMP', None)
        data = {
            #'timestamp': timestamp.strftime('%Y-%m-%d %H:%M:%S.%f'),
            'day': timestamp.date().isoformat(),
            'time': timestamp.time().isoformat(),
        }
        data.update(json.loads(entry.get('MESSAGE', None)))
        datas.append(data)
    writer = csv.DictWriter(sys.stdout, fieldnames=datas[0].keys())
    writer.writeheader()
    writer.writerows(datas)
